<!-- Begin Title, generated by Fern  -->
# Sayari-analytics Python Library

[![fern shield](https://img.shields.io/badge/%F0%9F%8C%BF-SDK%20generated%20by%20Fern-brightgreen)](https://github.com/fern-api/fern)

The Sayari-analytics Python Library provides convenient access to the Sayari-analytics API from applications written in Python.
<!-- End Title  -->

<!-- Begin Installation, generated by Fern  -->
# Installation

```sh
pip install --upgrade sayari
```
<!-- End Installation  -->

<!-- Begin Usage, generated by Fern  -->
# Usage

```python
from sayari.client import Client

client = Client(
    client_id="YOUR_CLIENT_ID",
    client_secret="YOUR_CLIENT_SECRET",
)
```
<!-- End Usage  -->

<!-- Begin Async Usage, generated by Fern  -->
# Async Client

```python
from sayari.client import AsyncClient

client = AsyncClient(
    client_id="YOUR_CLIENT_ID",
    client_secret="YOUR_CLIENT_SECRET",
)
```
<!-- End Async Usage  -->

<!-- Begin Status, generated by Fern  -->
# Beta Status

This SDK is in beta, and there may be breaking changes between versions without a major 
version update. Therefore, we recommend pinning the package version to a specific version. 
This way, you can install the same version each time without breaking changes.
<!-- End Status  -->

# Documentation
Please see our [docs site](http://documentation.sayari.com) for more info and or to get in touch with us.
